@@ -17,8 +17,8 @@ CHANNEL_EVENT = [
     "ProgramChange", "ChannelPressure", "PitchBend"
 ]
 META_EVENT = [
-    "MetaEvent", "Text", "TrackName", "Lyric", "Marker", "CuePoint", "SetBpm",
-    "TimeSignature", "KeySignature"
+    "MetaEvent", "Text", "Copyright", "Lyric", "Marker", "CuePoint", "TrackName", "SetBpm",
+    "TimeSignature", "KeySignature", "SequencerSpecific"
 ]
 EXTRA = ["EventSet"]
 
@@ -141,10 +141,6 @@ class _NoteEvent(ChannelEvent):
     __sub__ = partialmethod(down, inplace=False)
     __isub__ = partialmethod(down, inplace=True)
 
-    def _compare(self, a, b, op):
-        _a = (a.location, a.value, a.velocity, a.channel)
-        _b = (b.location, b.value, b.velocity, b.channel)
-        return op(_a, _b)
 
     @property
     def name(self) -> str:
@@ -211,6 +207,11 @@ class NoteOff(_NoteEvent):
                    location=core.convert.tick2loc(msg.time, ticks_per_beat),
                    channel=msg.channel)
 
+    def _compare(self, a, b, op):
+        _a = (a.location, a.value, a.velocity, a.channel)
+        _b = (b.location, b.value, b.velocity, b.channel)
+        return op(_a, _b)
+
     def copy(self) -> 'NoteOff':
         return self.__class__(self.value,
                               velocity=self.velocity,
@@ -254,6 +255,11 @@ class NoteOn(_NoteEvent):
                    location=core.convert.tick2loc(msg.time, ticks_per_beat),
                    channel=msg.channel)
 
+    def _compare(self, a, b, op):
+        _a = (a.location, a.value, a.velocity, a.channel)
+        _b = (b.location, b.value, b.velocity, b.channel)
+        return op(_a, _b)
+
     def copy(self) -> 'NoteOn':
         return self.__class__(self.value,
                               velocity=self.velocity,
@@ -291,10 +297,15 @@ class NotePressure(_NoteEvent):
             msg: Message,
             ticks_per_beat: int = DEFAULT_TICKS_PER_BEAT) -> 'NotePressure':
         return cls(msg.note,
-                   velocity=msg.velocity,
+                   pressure=msg.pressure,
                    location=core.convert.tick2loc(msg.time, ticks_per_beat),
                    channel=msg.channel)
 
+    def _compare(self, a, b, op):
+        _a = (a.location, a.value, a.pressure, a.channel)
+        _b = (b.location, b.value, b.pressure, b.channel)
+        return op(_a, _b)
+
     def copy(self) -> 'NotePressure':
         return self.__class__(self.value,
                               pressure=self.pressure,
@@ -307,7 +318,7 @@ class ControlChange(ChannelEvent):
 
     def __init__(self,
                  control: int,
-                 value: int,
+                 value: int = 0,
                  location: float = 0,
                  channel: int = 0) -> None:
         super().__init__(location, channel)
@@ -547,11 +558,11 @@ class TrackName(MetaEvent):
         self.name = name
 
     def __repr__(self) -> str:
-        return f'{self.__class__.__name__}(text="{repr(self.text)[1:-1]}", location={self.location:.2f})'
+        return f'{self.__class__.__name__}(name="{repr(self.name)[1:-1]}", location={self.location:.2f})'
 
     def message(self, ticks_per_beat=DEFAULT_TICKS_PER_BEAT) -> MetaMessage:
         return MetaMessage(self.message_type,
-                           text=self.text,
+                           name=self.name,
                            time=core.convert.loc2tick(self.location,
                                                       ticks_per_beat))
 
@@ -677,6 +688,9 @@ class SequencerSpecific(MetaEvent):
     def __init__(self, data, location: float = 0) -> None:
         super().__init__(location)
         self.data = data
+
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}(data={self.data}, location={self.location:.2f})'
     
     def message(self, ticks_per_beat=DEFAULT_TICKS_PER_BEAT) -> MetaMessage:
         return MetaMessage("sequencer_specific",
