@@ -1,6 +1,9 @@
 from .controller import *
 from .fluidsynth import *
+from .viewer import *
 
 __all__ = []
 __all__.extend(controller.__all__)
-__all__.extend(fluidsynth.__all__)
\ No newline at end of file
+__all__.extend(fluidsynth.__all__)
+__all__.extend(viewer.__all__)
+
